==> cscec5b-wzxt-impl-3.0.0-20210323.102203-181-sources.jar: com/ejianc/business/wzxt/service/impl/ExitApplyBpmServiceImpl.java <==
package com.ejianc.business.wzxt.service.impl;

import com.ejianc.business.wzxt.bean.ExitApplyEntity;
import com.ejianc.business.wzxt.service.CommonSupportService;
import com.ejianc.business.wzxt.service.IExitApplyService;
import com.ejianc.business.wzxt.service.IOrderService;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

@Service("exitApply")
public class ExitApplyBpmServiceImpl implements ICommonBusinessService {

    private final Logger logger = LoggerFactory.getLogger(getClass());


    @Autowired
    private IExitApplyService service;


    @Autowired
    private CommonSupportService commonSupportService;

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        ExitApplyEntity exitApplyEntity = service.selectById(billId);

        //推送供方
        Map<String, String> headers = new HashMap<>();
        CommonResponse<String> tokenres = commonSupportService.getAccessToken(headers);
        if (tokenres.isSuccess()) {
            logger.info("获取供方token--" + headers);
            CommonResponse<String> pushres = service.pushConfirmEntity(headers, exitApplyEntity);
            logger.info("获取推送供方结果--" + pushres);
            if (pushres.isSuccess()) {
                //推送成功后处理逻辑
                if (BillStateEnum.COMMITED_STATE.getBillStateCode() == state) {
                    exitApplyEntity.setCommitId(InvocationInfoProxy.getUserid());
                }
                service.saveOrUpdate(exitApplyEntity, false);
            } else {
                return pushres;
            }
        } else {
            return tokenres;
        }
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}

==> cscec5b-wzxt-impl-3.0.0-20210324.081859-192-sources.jar: com/ejianc/business/wzxt/service/impl/ExitApplyBpmServiceImpl.java <==
package com.ejianc.business.wzxt.service.impl;

import com.ejianc.business.wzxt.bean.ExitApplyEntity;
import com.ejianc.business.wzxt.bean.ExitEntity;
import com.ejianc.business.wzxt.service.CommonSupportService;
import com.ejianc.business.wzxt.service.IExitApplyService;
import com.ejianc.business.wzxt.service.IOrderService;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

@Service("exitApply")
public class ExitApplyBpmServiceImpl implements ICommonBusinessService {

    private final Logger logger = LoggerFactory.getLogger(getClass());


    @Autowired
    private IExitApplyService service;


    @Autowired
    private CommonSupportService commonSupportService;

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        ExitApplyEntity exitEntity = service.selectById(billId);
        exitEntity.setCommitId(InvocationInfoProxy.getUserid());
        service.saveOrUpdate(exitEntity,false);
        return CommonResponse.success();
    }

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        ExitApplyEntity exitApplyEntity = service.selectById(billId);

        //推送供方
        Map<String, String> headers = new HashMap<>();
        CommonResponse<String> tokenres = commonSupportService.getAccessToken(headers);
        if (tokenres.isSuccess()) {
            logger.info("获取供方token--" + headers);
            CommonResponse<String> pushres = service.pushConfirmEntity(headers, exitApplyEntity);
            logger.info("获取推送供方结果--" + pushres);
            if (pushres.isSuccess()) {
                //推送成功后处理逻辑
                if (BillStateEnum.COMMITED_STATE.getBillStateCode() == state) {
                    exitApplyEntity.setCommitId(InvocationInfoProxy.getUserid());
                }
                service.saveOrUpdate(exitApplyEntity, false);
            } else {
                return pushres;
            }
        } else {
            return tokenres;
        }
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}
